.. pyaardvark documentation master file, created by
   sphinx-quickstart on Mon Feb 10 10:18:01 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to pyaardvark's documentation!
======================================

Contents:

.. toctree::
   :maxdepth: 2

   intro
   api



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

